Intervention Policies
===================================

This module provides policies for selecting which concepts to intervene on during inference.

.. currentmodule:: torch_concepts.nn

Summary
-------

**Policy Classes**

.. autosummary::
   :toctree: generated
   :nosignatures:

   UniformPolicy
   RandomPolicy
   UncertaintyInterventionPolicy


Class Documentation
-------------------

.. autoclass:: UniformPolicy
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: RandomPolicy
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: UncertaintyInterventionPolicy
   :members:
   :undoc-members:
   :show-inheritance:
